<img align="center" src="docs/content/img/title.png">

# kraken-core

[![Python application](https://github.com/kraken-build/kraken-core/actions/workflows/python-package.yml/badge.svg)](https://github.com/kraken-build/kraken-core/actions/workflows/python-package.yml)
[![PyPI version](https://badge.fury.io/py/kraken-core.svg)](https://badge.fury.io/py/kraken-core)

Kraken is a task orchestration system with a focus on ease of configuration and flexibility. It's main objectives are
to reduce boilerplate and configuration overhead in software projects and to model and abstract complex workflows in
the software development lifecycle to allow developers to focus on what really matters.

Read more about the Kraken core package in the [documentation][].

  [documentation]: https://kraken-build.github.io/kraken-core/
